def get_color(i):

    # Colors
    nature_palette = [  "#E64B35FF", 
                        "#4DBBD5FF", 
                        "#00A087FF", 
                        "#3C5488FF", 
                        "#F39B7FFF", 
                        "#8491B4FF", 
                        "#91D1C2FF", 
                        "#DC0000FF", 
                        "#7E6148FF", 
                        "#B09C85FF", 
                        "#E64B35CC", 
                        "#4DBBD5CC", 
                        "#00A087CC", 
                        "#3C5488CC", 
                        "#F39B7FCC", 
                        "#8491B4CC", 
                        "#91D1C2CC", 
                        "#DC0000CC", 
                        "#7E6148CC", 
                        "#B09C85CC", 
                        "#E64B3599", 
                        "#4DBBD599", 
                        "#00A08799", 
                        "#3C548899", 
                        "#F39B7F99", 
                        "#8491B499", 
                        "#91D1C299", 
                        "#DC000099", 
                        "#7E614899", 
                        "#B09C8599"
                   ]

    n = len(nature_palette)


    return nature_palette[i%n]
    


def get_marker(i):

    # Markers
    markers = ["o", "^", "s", "*", "p", "X"]

    n = len(markers)


    return markers[i%n]